@@ -24,13 +24,51 @@ from memberpress_client.decorators import request_manager
 # -------------------------------
 # /usr/local/lib/python3.9/site-packages/urllib3/connectionpool.py:1043:
 # InsecureRequestWarning: Unverified HTTPS request is being made to host 'staging.global-communications-academy.com'.
-# Adding certificate verification is strongly advised. See: https://urllib3.readthedocs.io/en/1.26.x/advanced-usage.html#ssl-warnings
+# Adding certificate verification is strongly advised. See: https://urllib3.readtheocs.io/en/1.26.x/advanced-usage.html#ssl-warnings
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 logger = logging.getLogger(__name__)
 
 
 class MemberpressAPIClient:
+    _locked = False
+    _json = None
+
+    def init(self):
+        self._locked = False
+        self._json = None
+
+    def lock(self):
+        self._locked = True
+
+    def unlock(self):
+        self._locked = False
+
+    @property
+    def locked(self):
+        return self._locked
+
+    @property
+    def json(self):
+        return self._json
+
+    @json.setter
+    def json(self, value):
+        if type(value) == dict or value is None:
+            self.init()
+            self._json = value
+        else:
+            logger.warning("was expecting a value of type dict but receive type {t}".format(t=type(value)))
+
+    @property
+    def ready(self):
+        return True if not self.locked and self.json and len(self.json) > 0 else False
+
+    def is_valid(self, value) -> bool:
+        if type(value) != dict:
+            return False
+        return True
+
     def get_url(self, path) -> str:
         return urljoin(settings.MEMBERPRESS_API_BASE_URL, path)
 
@@ -69,23 +107,30 @@ class MemberpressAPIClient:
         cache_key = f"MemberpressAPIClient.get:{url}"
         response = cache.get(cache_key)
 
-        if response == "locked":
-            return None
+        if not response and not self.locked:
+            # set a lock to prevent multiple calls
+            self.lock()
+
+            # purge whatever might have previously existing in the cache, in case our
+            # response object raises an exception here ...
+            cache.delete(cache_key)
 
-        if not response:
-            cache.set(cache_key, "locked", settings.MEMBERPRESS_CACHE_EXPIRATION)
             log_pretrip(caller=inspect.currentframe().f_code.co_name, url=url, data={}, operation=operation)
             response = requests.get(url, params=params, headers=self.headers, verify=False)
-            cache.delete(cache_key)
             log_postrip(caller=inspect.currentframe().f_code.co_name, path=url, response=response, operation=operation)
+
+            # @request_manager will create verbose log entries for any responses outside of 200-299.
             response.raise_for_status()
 
-            try:
-                response = response.json()
-            except Exception:
-                response = json.dumps(response)
+            if type(response) not in [dict, list]:
+                try:
+                    response = response.json()
+                except Exception:
+                    response = json.dumps(response)
 
+            # caching results iff response is a valid json object.
             cache.set(cache_key, response, settings.MEMBERPRESS_CACHE_EXPIRATION)
+            self.unlock()
         return response
 
     def is_valid_dict(self, response, qc_keys) -> bool:
