@@ -26,10 +26,8 @@ class Member(MemberpressAPIClient):
     """
 
     _request = None
-    _member = None
     _username = None
     _is_validated_member = False
-    _locked = False
 
     _recent_subscriptions = None
     _recent_transactions = None
@@ -47,7 +45,7 @@ class Member(MemberpressAPIClient):
         super().__init__()
         self.init()
         self.request = request
-        self._member = response
+        self.json = response
 
         if response:
             self.validate_response_object()
@@ -77,9 +75,13 @@ class Member(MemberpressAPIClient):
         if username:
             self._username = username
 
+        if self.username:
+            # invoke the getter
+            self.member
+
     def init(self):
+        super().init()
         self._request = None
-        self._member = None
         self._username = None
         self._is_validated_member = False
         self._recent_subscriptions = None
@@ -133,10 +135,6 @@ class Member(MemberpressAPIClient):
         else:
             raise TypeError("Was expecting value of type request but received object of type {t}".format(t=type(value)))
 
-    @property
-    def ready(self):
-        return True if len(self.member) > 0 and not self._locked else False
-
     @property
     def member(self) -> dict:
         """
@@ -147,11 +145,10 @@ class Member(MemberpressAPIClient):
         an empty dict {} for the life of the object instance.
         """
         # note: need to use private _username in order to avoid recursion.
-        if self._username and not self._member and not self._locked:
+        if self._username and not self.json and not self.locked:
             """
             expected result is a list containing 1 dict
             """
-            self._locked = True
             path = MemberPressAPI_Endpoints.MEMBERPRESS_API_MEMBER_PATH(username=self._username)
             retval = self.get(path=path, operation=MemberPressAPI_Operations.GET_MEMBER)
 
@@ -166,16 +163,15 @@ class Member(MemberpressAPIClient):
 
                 if len(retval) == 1:
                     retval = retval[0]
-                    if type(retval) != dict:
+                    if not self.is_valid(retval):
                         logger.warning(
                             "member() was expecting a return type of dict but received {t}.".format(t=type(retval))
                         )
                         retval = None
-                self._member = retval
-            self._locked = False
+                self.json = retval
         # convert NoneType to a dict so that other class properties
         # can safely use the form, val = self.member.get("blah")
-        return self._member or {}
+        return self.json or {}
 
     @property
     def id(self) -> int:
@@ -390,11 +386,17 @@ class Member(MemberpressAPIClient):
     def is_trial_subscription(self) -> bool:
         if not self.is_validated_member:
             return False
+
         now = datetime.now()
         for membership in self.active_memberships:
             expire_date = membership.expire_fixed or now
-            logger.info("expre_idate = {dt}".format(dt=expire_date))
             if expire_date >= now:
                 return True
 
         return False
+
+    @property
+    def should_raise_paywall(self) -> bool:
+        if self.is_active_subscription or self.is_trial_subscription:
+            return False
+        return self.ready
