@@ -31,4 +31,9 @@ INSTALLED_APPS = []
 ALLOWED_HOSTS = []
 EMAIL_BACKEND = None
 USE_I18N = False
-CACHES = []
+CACHES = CACHES = {
+    "default": {
+        "BACKEND": "django.core.cache.backends.filebased.FileBasedCache",
+        "LOCATION": ".//django_cache",
+    }
+}
